@@ -17,23 +17,17 @@
 
 import pygame
 
-from trosnoth.data import fonts, getPath
-
 _cache = {}
 
-def get(name, size):
+def get(filename, size):
     try:
-        return _cache[name, size]
+        return _cache[filename, size]
     except KeyError:
-        if name is not None:
-            filename = getPath(fonts, name)
-        else:
-            filename = None
         try:
             result = pygame.font.Font(filename, size)
         except IOError:
             print 'Font Cache: unable to load font %r' % (filename,)
             result = pygame.font.Font(None, size)
 
-        _cache[name, size] = result
+        _cache[filename, size] = result
         return result
