@@ -37,12 +37,12 @@ defaultKeys = (
     ('more actions', pygame.K_v),
     ('respawn', pygame.K_r),
 
-    ('turret', pygame.K_F1),
-    ('shield', pygame.K_F2),
-    ('minimap disruption', pygame.K_F3),
-    ('phase shift', pygame.K_F4),
-    ('grenade', pygame.K_F5),
-    ('ricochet', pygame.K_F6),
+    ('turret', pygame.K_1),
+    ('shield', pygame.K_2),
+    ('minimap disruption', pygame.K_3),
+    ('phase shift', pygame.K_4),
+    ('grenade', pygame.K_5),
+    ('ricochet', pygame.K_6),
 
     ('abandon', pygame.K_m),
     ('chat', pygame.K_RETURN),
@@ -51,7 +51,7 @@ defaultKeys = (
     ('leaderboard', pygame.K_p),
     ('toggle interface', pygame.K_DELETE),
 
-    ('toggle terminal', pygame.K_F9),
+    ('toggle terminal', pygame.K_SCROLLOCK),
 )
 
 default_game_keys = VirtualKeySet(defaultKeys)
