@@ -210,6 +210,16 @@ class RequestPlayersMsg(NetworkMessage):
     fields = ()
     packspec = ''
 
+class RequestZonesMsg(NetworkMessage):
+    idString = 'RqZn'
+    fields = ()
+    packspec = ''
+
+class ZoneStateMsg(NetworkMessage):
+    idString = 'ZnSt'
+    fields = 'zoneId', 'teamId', 'dark'
+    packspec = 'Icb'
+
 ####################
 # Shot
 ####################
@@ -244,8 +254,8 @@ class ShotFiredMsg(NetworkMessage):
 
 class DeleteUpgradeMsg(NetworkMessage):
     idString = 'DUpg'
-    fields = 'playerId'
-    packspec = 'c'
+    fields = 'playerId', 'upgradeType'
+    packspec = 'cc'
 
 class BuyUpgradeMsg(NetworkMessage):
     '''
@@ -286,6 +296,7 @@ class CannotBuyUpgradeMsg(NetworkMessage):
         'E' - too close to zone edge
         'O' - too close to orb
         'F' - not in a dark friendly zone
+        'M' - your team has a minimap disruption in use
     '''
     idString = 'NotU'
     fields = 'playerId', 'reasonId', 'tag'
@@ -327,6 +338,9 @@ tcpMessages = set([
     RequestMapBlockLayoutMsg,
     MapBlockLayoutMsg,
     RequestPlayersMsg,
+    RequestZonesMsg,
+    ZoneStateMsg,
     RequestUDPStatusMsg,
     NotifyUDPStatusMsg,
+    PlayerHasUpgradeMsg,
 ])
