@@ -25,7 +25,7 @@ from trosnoth.src.messages import (ChatMsg, TaggingZoneMsg, PlayerStarsSpentMsg,
         CannotJoinMsg, JoinSuccessfulMsg, UpdatePlayerStateMsg, AimPlayerAtMsg,
         RemovePlayerMsg, SetCaptainMsg, TeamIsReadyMsg, QueryWorldParametersMsg,
         SetWorldParametersMsg, RequestMapBlockLayoutMsg, MapBlockLayoutMsg,
-        ConnectionLostMsg, NotifyUDPStatusMsg)
+        ConnectionLostMsg, NotifyUDPStatusMsg, ZoneStateMsg)
 from twisted.internet import reactor
 
 REQUEST_TIMEOUT = 2
@@ -116,6 +116,7 @@ class AgentFilter(Component):
     @handler(ConnectionLostMsg, gameEvents)
     @handler(ChatMsg, gameEvents)
     @handler(NotifyUDPStatusMsg, gameEvents)
+    @handler(ZoneStateMsg, gameEvents)
     def passToAgent(self, msg):
         self.agentEvents.send(msg)
 
