@@ -419,10 +419,10 @@ class MapBlock(object):
         shot.registeredHit = True
         if player.phaseshift:
             self.universe.eventPlug.send(KillShotMsg(shooterId, shot.id))
-        elif player.shielded and player.upgrade.protections == 1:
+        elif player.shielded and player.upgrade.protections <= 1:
             self.universe.eventPlug.send(KillShotMsg(shooterId, shot.id))
-            self.universe.eventPlug.send(DeleteUpgradeMsg(player.id))
-        elif player.health == 1:
+            self.universe.eventPlug.send(DeleteUpgradeMsg(player.id, player.upgrade.upgradeType))
+        elif player.health <= 1:
             player.deathDetected(shooterId, shot.id)
         else:
             self.universe.eventPlug.send(PlayerHitMsg(player.id, shooterId,
