@@ -229,7 +229,7 @@ class Player(Unit):
             self.upgradeGauge -= deltaT
             if self.upgradeGauge <= 0:
                 self.upgrade.timeIsUp()
-                self.universe.eventPlug.send(DeleteUpgradeMsg(self.id))
+                self.universe.eventPlug.send(DeleteUpgradeMsg(self.id, self.upgrade.upgradeType))
 
         #########
         # GHOST #
@@ -430,6 +430,8 @@ class Player(Unit):
         self._jumpTime = 0
         self._setStarsForDeath()
         checkpoint('Player: died')
+        if self.upgrade is not None and self.upgrade.goneWhenDie():
+            self.universe.eventPlug.send(DeleteUpgradeMsg(self.id, self.upgrade.upgradeType))
 
     def deathDetected(self, shooterId, shotId):
         self.universe.eventPlug.send(PlayerKilledMsg(self.id,
