@@ -19,5 +19,5 @@ from trosnoth.src.utils.utils import new
 
 class GameState(object):
     '''Enumeration for the state of the game.'''
-    PreGame, InProgress, Ended = new(3)
+    PreGame, Starting, InProgress, Ended = new(4)
 
