@@ -25,7 +25,7 @@ from trosnoth.src.messages import (ChatMsg, TaggingZoneMsg, NotifyUDPStatusMsg,
         CannotRespawnMsg, AddPlayerMsg, JoinSuccessfulMsg, UpdatePlayerStateMsg,
         AimPlayerAtMsg, RemovePlayerMsg, CannotJoinMsg, SetCaptainMsg,
         TeamIsReadyMsg, InitClientMsg, ConnectionLostMsg,
-        SetWorldParametersMsg, MapBlockLayoutMsg, tcpMessages)
+        SetWorldParametersMsg, MapBlockLayoutMsg, ZoneStateMsg, tcpMessages)
 from trosnoth.src.utils.components import Component, Plug
 from trosnoth.src.utils.unrepr import unrepr
 from twisted.internet import defer, reactor
@@ -60,8 +60,13 @@ clientMsgs = netmsg.MessageCollection(
     CannotRespawnMsg,
     CannotBuyUpgradeMsg,
     ChatMsg,
+    ZoneStateMsg,
 )
 
+class ConnectionFailed(Exception):
+    def __init__(self, reason):
+        self.reason = reason
+
 class ClientNetHandler(Component):
     requestPlug = Plug()
     eventPlug = Plug()
@@ -92,7 +97,7 @@ class ClientNetHandler(Component):
     def _timedOut(self):
         if self.connId is None or not self.validated:
             if self._deferred is not None:
-                self._deferred.errback(IOError('timed out'))
+                self._deferred.errback(ConnectionFailed('Timed out.'))
                 self._deferred = None
 
     def cancelConnecting(self):
@@ -125,7 +130,7 @@ class ClientNetHandler(Component):
         svrVersion = settings.get('serverVersion', 'server.v1.0.0+')
         if svrVersion not in validServerVersions:
             print 'Client: bad server version %s' % (svrVersion,)
-            self._deferred.errback(IOError('Incompatible server version.'))
+            self._deferred.errback(ConnectionFailed('Incompatible server version.'))
             self._deferred = None
             self.netman.closeConnection(self.connId)
             self.connId = None
@@ -177,7 +182,7 @@ class ClientNetHandler(Component):
 
     def receiveBadString(self, connId, line):
         if self._deferred is not None:
-            self._deferred.errback(IOError('Remote host sent unexpected '
+            self._deferred.errback(ConnectionFailed('Remote host sent unexpected '
                     'message: %r' % (line,)))
             self._deferred = None
             self.connId = None
@@ -191,14 +196,14 @@ class ClientNetHandler(Component):
         self.connId = None
         if self._deferred is not None:
             self._deferred.errback(
-                    IOError('Remote server dropped connection.'))
+                    ConnectionFailed('Remote server dropped connection.'))
             self._deferred = None
             return
         self.eventPlug.send(ConnectionLostMsg())
 
     def connectionFailed(self, connId):
         if self._deferred is not None:
-            self._deferred.errback(IOError('Timed out.'))
+            self._deferred.errback(ConnectionFailed('Timed out.'))
             self._deferred = None
             self.connId = None
 
