@@ -26,7 +26,7 @@ from trosnoth.src.messages import (ChatMsg, InitClientMsg,
         RequestUDPStatusMsg, NotifyUDPStatusMsg,
         DeleteUpgradeMsg, BuyUpgradeMsg, ShootMsg, RespawnRequestMsg,
         JoinRequestMsg, UpdatePlayerStateMsg, AimPlayerAtMsg, SetCaptainMsg,
-        TeamIsReadyMsg, tcpMessages)
+        TeamIsReadyMsg, RequestZonesMsg, tcpMessages)
 from trosnoth.src.utils.event import Event
 
 # The set of messages that the server expects to receive.
@@ -44,6 +44,7 @@ serverMsgs = netmsg.MessageCollection(
     RespawnRequestMsg,
     JoinRequestMsg,
     RequestPlayersMsg,
+    RequestZonesMsg,
     ChatMsg,
 )
 class ServerNetHandler(object):
