@@ -92,9 +92,12 @@ class ChatBox(MoveableBox):
         self.Close()
     
     def hitEnter(self, senderValue):
-        self.result = DialogResult.OK
-        self.sendChat(senderValue)
-        self.Close()
+        if senderValue == '':
+            self.cancel()
+        else:
+            self.result = DialogResult.OK
+            self.sendChat(senderValue)
+            self.Close()
 
     def sendChat(self, senderValue):
         # Interpret lines with initial hash.
