@@ -339,7 +339,7 @@ class DetailsInterface(framework.CompoundElement):
                 self.elements.remove(self.unobtrusiveGetter)
                 self.unobtrusiveGetter = None
             if abandon:
-                self.controller.send(DeleteUpgradeMsg(player.id))
+                self.controller.send(DeleteUpgradeMsg(player.id, player.upgrade.upgradeType))
 
         self.unobtrusiveGetter.onGotValue.addListener(gotValue)
 
