@@ -51,7 +51,7 @@ from trosnoth.src.messages import (TaggingZoneMsg, ChatFromServerMsg, ChatMsg,
         CannotJoinMsg, AddPlayerMsg, UpdatePlayerStateMsg, AimPlayerAtMsg,
         RemovePlayerMsg, PlayerHasUpgradeMsg, PlayerStarsSpentMsg,
         DeleteUpgradeMsg, CannotBuyUpgradeMsg, ConnectionLostMsg,
-        NotifyUDPStatusMsg)
+        NotifyUDPStatusMsg, ZoneStateMsg)
 
 from twisted.internet import defer, reactor
 
@@ -114,6 +114,7 @@ class GameInterface(framework.CompoundElement, Component):
     @handler(AimPlayerAtMsg, eventPlug)
     @handler(SetGameModeMsg, eventPlug)
     @handler(PlayerUpdateMsg, eventPlug)
+    @handler(ZoneStateMsg, eventPlug)
     def ignoreMessage(self, msg):
         pass
 
@@ -372,6 +373,8 @@ class GameInterface(framework.CompoundElement, Component):
                 text = 'You are too close to the orb.'
             elif msg.reasonId == 'F':
                 text = 'You are not in a dark friendly zone.'
+            elif msg.reasonId == 'M':
+                text = 'Your team is already using a minimap disruption.'
             else:
                 text = 'You cannot buy that upgrade at this time.'
             self.detailsInterface.newMessage(text)
@@ -383,10 +386,8 @@ class GameInterface(framework.CompoundElement, Component):
             self.detailsInterface.upgradeUsed(player)
             upgrade = self.world.getUpgradeType(msg.upgradeType)
             if upgrade == MinimapDisruption:
-                # TODO player.upgrade may still be None here.
                 self.gameViewer.minimapDisruption(player)
             elif upgrade == Grenade:
-                # TODO player.upgrade may still be None here.
                 self.gameViewer.worldgui.addGrenade(player.upgrade.gr)
         except Abort:
             pass
@@ -396,14 +397,12 @@ class GameInterface(framework.CompoundElement, Component):
         try:
             player = self.world.getPlayer(msg.playerId)
             self.detailsInterface.upgradeDestroyed(player, player.upgrade)
-            if isinstance(player.upgrade, MinimapDisruption):
-                # TODO: player.upgrade may be None here.
+            if isinstance(player.upgrade, MinimapDisruption) or msg.upgradeType == MinimapDisruption.upgradeType:
                 self.gameViewer.endMinimapDisruption(player)
             elif isinstance(player.upgrade, Grenade):
-                # TODO: player.upgrade may be None here.
                 self.gameViewer.worldgui.removeGrenade(player.upgrade.gr)
         except Abort:
-            pass
+            print 'Unable to remove upgrade: %s' % (msg.playerId,)
 
     @handler(ChatFromServerMsg, eventPlug)
     def gotChatFromServer(self, msg):
