@@ -48,12 +48,12 @@ class GaugeBase(framework.Element):
     # Return a number as a proportion (0..1) of how complete
     # this box is. To be implemented in subclasses
     def getRatio(self):
-        raise NotImplementedException
+        raise NotImplementedError
 
     # Return the foreground colour that this gauge should be.
     # To be implemented in subclasses
     def getForeColour(self):
-        raise NotImplementedException
+        raise NotImplementedError
 
     # Return the background colour that this gauge should be.
     # None = blank
@@ -89,7 +89,8 @@ class TurretGauge(GaugeBase):
         self.player = player
 
     def getRatio(self):
-        return min(1, self.player.turretHeat / self.player.turretHeatCapacity)
+        return max(0, min(1, self.player.turretHeat /
+                self.player.turretHeatCapacity))
 
     def getForeColour(self):
         if self.player.turretOverHeated:
@@ -107,7 +108,10 @@ class UpgradeGauge(GaugeBase):
         self.player = player
 
     def getRatio(self):
-        return min(self.player.upgradeGauge / self.player.upgradeTotal, 1)
+        if self.player.upgradeTotal == 0:
+            return 1
+        return max(0, min(1, self.player.upgradeGauge /
+                self.player.upgradeTotal))
 
     def getForeColour(self):
         return self.app.theme.colours.gaugeUpgradeFore
