@@ -249,8 +249,7 @@ class LeaderBoard(framework.CompoundElement):
                             self.app.theme.colours.leaderboardNormal
 
             # Add the "star total" row
-            if (len(players) > 1 and (team is self.friendlyTeam or
-                    self.spectator) and self.world.gameState not in
+            if (len(players) > 1 and self.world.gameState not in
                     (GameState.PreGame, GameState.Starting)):
                 count += 1
                 self.playerTable.addRow()
