@@ -49,7 +49,7 @@ class MiniMap(framework.Element):
         interfaceBlockSize = (MapLayout.zoneInterfaceWidth /scale,
                               MapLayout.halfZoneHeight / scale)
         self.interfaceBlockRect = pygame.Rect((0,0), interfaceBlockSize)
-
+        self.disruptAnimation = self.createDisrupted()
         # self._focus represents the point where the miniMap is currently
         # looking.
         self._focus = None
@@ -89,6 +89,30 @@ class MiniMap(framework.Element):
     def getRect(self):
         return pygame.Rect(self.getOffset(), self.getSize())
 
+    def createDisrupted(self):
+        # TODO: Callthis again if the size changes
+        screens = []
+        sRect = self.getRect()
+        for a in range(0,4):
+            screen = (pygame.surface.Surface(sRect.size))
+            x = y = yy = 0
+            rect = pygame.rect.Rect(0,0,2,2)
+            disruptColours = disruptColours = [self.app.theme.colours.minimapDisruptionColour1, self.app.theme.colours.minimapDisruptionColour2]
+            
+            while x < sRect.right:
+                while y < sRect.bottom:
+                    rect.top = y
+                    pygame.draw.rect(screen, random.choice(disruptColours), rect, 0)
+                    y += 2
+                y = yy
+                rect.left = x
+                x += 2
+            screens.append(screen)
+        return Animation(0.1, *screens)
+    
+    def drawDisrupted(self, screen):
+        screen.blit(self.disruptAnimation.getImage(), self.getOffset())
+        
     def draw(self, screen):
         '''Draws the current state of the universe at the current viewing
         location on the screen.  Does not call pygame.display.flip() .'''
@@ -100,50 +124,53 @@ class MiniMap(framework.Element):
         # If disrupted, draw static 95% of the time
         if self.disrupt and random.random() > 0.05:
             self.drawDisrupted(screen)
-            return
+        else:
+            # Update where we're looking at.
+            self.updateFocus()
 
-        # Update where we're looking at.
-        self.updateFocus()
+            self.drawZones(screen)
 
-        self.drawZones(screen)
+            # DRAW PLAYERS
 
-        # DRAW PLAYERS
+            # Go through and update the positions of the players on the screen.
+            for player in self.universe.players:
+                # Calculate the position of the player.
+                playerPos = [(player.pos[i] - self._focus[i]) / self.scale + \
+                                      sRect.center[i] for i in (0,1)]
+                if sRect.collidepoint(*playerPos):
 
-        # Go through and update the positions of the players on the screen.
-        for player in self.universe.players:
-            # Calculate the position of the player.
-            playerPos = [(player.pos[i] - self._focus[i]) / self.scale + \
-                                  sRect.center[i] for i in (0,1)]
-            if sRect.collidepoint(*playerPos):
+                    # The player being drawn is the one controlled by the user.
+                    if (hasattr(self.viewManager.target, 'player') and player ==
+                            self.viewManager.target.player):
+                        clr = colours.minimapOwnColour
+                        radius = 3
 
-                # The player being drawn is the one controlled by the user.
-                if (hasattr(self.viewManager.target, 'player') and player ==
-                        self.viewManager.target.player):
-                    clr = colours.minimapOwnColour
-                    radius = 3
-
-                else:
-                    if player.ghost:
-                        clr = self.app.theme.colours.miniMapGhostColour(
-                                player.team)
                     else:
-                        clr = self.app.theme.colours.miniMapPlayerColour(
-                                player.team)
-                    radius = 2
-                playerPos = [int(playerPos[i]) for i in (0,1)]
-                pygame.draw.circle(screen, clr, playerPos, radius)
+                        if player.ghost:
+                            clr = self.app.theme.colours.miniMapGhostColour(
+                                    player.team)
+                        else:
+                            clr = self.app.theme.colours.miniMapPlayerColour(
+                                    player.team)
+                        radius = 2
+                    playerPos = [int(playerPos[i]) for i in (0,1)]
+                    pygame.draw.circle(screen, clr, playerPos, radius)
 
 
 
 
-        # Draw the shots.
-        for shot in self.universe.shots:
-            # Calculate the position of the player.
-            shotPos = [(shot.pos[i] - self._focus[i]) / self.scale + \
-                    sRect.center[i] for i in (0,1)]
-            if sRect.collidepoint(*shotPos):
-                shotPos = [int(shotPos[i]) for i in (0,1)]
-                pygame.draw.circle(screen, colours.white, shotPos, 0)
+            # Draw the shots.
+            for shot in self.universe.shots:
+                # Calculate the position of the player.
+                shotPos = [(shot.pos[i] - self._focus[i]) / self.scale + \
+                        sRect.center[i] for i in (0,1)]
+                if sRect.collidepoint(*shotPos):
+                    shotPos = [int(shotPos[i]) for i in (0,1)]
+                    pygame.draw.circle(screen, colours.white, shotPos, 0)
+
+        # Finally, draw the border
+        pygame.draw.rect(screen, self.app.theme.colours.minimapBorder,
+                sRect, 2)
 
     def drawZones(self, screen):
         '''Draws the miniMap graphics onto the screen'''
@@ -198,8 +225,6 @@ class MiniMap(framework.Element):
             posToDraw[1] += self.interfaceBlockRect.height
             if posToDraw[1] > sRect.bottom:
                 break
-        pygame.draw.rect(screen, self.app.theme.colours.minimapBorder,
-                sRect, 2)
 
     def _drawBlockMiniBg(self, block, surface, rect, area=None):
         if block.defn.kind == 'fwd':
@@ -340,24 +365,3 @@ class MiniMap(framework.Element):
 
     def endDisruption(self):
         self.disrupt = False
-
-    def drawDisrupted(self, screen):
-        sRect = self.getRect()
-        x,y = sRect.topleft
-
-        yy = y
-        rect = pygame.rect.Rect(0,0,2,2)
-        disruptColours = [colours.black, colours.white]
-        while x < sRect.right:
-            rect.left = x
-            while y < sRect.bottom:
-                rect.top = y
-                pygame.draw.rect(screen, random.choice(disruptColours), rect, 0)
-                y += 2
-            y = yy
-            x += 2
-
-        # Border:
-        pygame.draw.rect(screen, self.app.theme.colours.minimapBorder, sRect, 2)
-
-
