@@ -18,6 +18,7 @@
 import pygame
 from trosnoth.src.gui.framework.basics import AngledImageCollection, Animation
 from trosnoth.src.trosnothgui import defines
+from trosnoth.src.trosnothgui.ingame.nametag import NameTag, StarTally
 
 from trosnoth.src.model.obstacles import VerticalWall
 import random
@@ -61,10 +62,11 @@ class PlayerSprite(pygame.sprite.Sprite):
         super(PlayerSprite, self).__init__()
         self.app = app
         self.player = player
-        self.nametag = player.nametag
+        self.nametag = NameTag(app, player.nick)
+        self.starTally = StarTally(app, 0)
 
         sprites = app.theme.sprites
-        gunImages = AngledImageCollection(self,
+        gunImages = AngledImageCollection(self.getAngleFacing,
                 *sprites.gunImages(self.player.team))
 
         self.runningAnimation = [
@@ -124,20 +126,17 @@ class PlayerSprite(pygame.sprite.Sprite):
     def pos(self):
         return self.player.pos
 
+    def getAngleFacing(self):
+        return self.player.angleFacing
+
     @property
     def angleFacing(self):
         return self.player.angleFacing
-    
-    # This is hopefully a temporary fix to facilitate
-    # the problem we have with angleFacing being given
-    # values outside of the range -pi < x <= pi.as_integer_ratio
-    # You can tell when this happens because it should print
-    # "AIC: Weird angleFacing...". Would be better to fix it at the root.
-    def setAngleFacing(self, value):
-        self.player.setAngleFacing(value)
 
-    # TODO: this is a bit hacky. Do those things accessing self.player actually need them?
     def __getattr__(self, attr):
+        '''
+        Proxy attributes through to the underlying player class.
+        '''
         return getattr(self.player, attr)
 
     def update(self):
