@@ -38,7 +38,7 @@ from trosnoth.src.trosnothgui.ingame.sprites import PlayerSprite
 
 from trosnoth.src.gui.common import Location, FullScreenAttachedPoint
 
-class ViewManager(framework.CompoundElement):
+class ViewManager(framework.Element):
     '''A ViewManager object takes a given universe, and displays a screenfull
     of the current state of the universe on the specified screen object.  This
     class displays only a section of the universe and no other information
@@ -358,7 +358,6 @@ class ViewManager(framework.CompoundElement):
         if isinstance(self.target, PlayerSprite):
             # Take into account where the player's looking.
             plPos = self.target.pos
-            plAngle = self.target.angleFacing
 
             if self.app.displaySettings.centreOnPlayer:
                 targetPt = plPos
@@ -368,6 +367,7 @@ class ViewManager(framework.CompoundElement):
                 #if radius == None or radius > self.lengthFromPlayer:
                 #    radius = self.lengthFromPlayer
                     
+                plAngle = self.target.angleFacing
                 targetPt = (plPos[0] + radius * sin(plAngle),
                             plPos[1] - radius * cos(plAngle))
 
@@ -426,7 +426,7 @@ class ViewManager(framework.CompoundElement):
                             if count > maxP:
                                 maxP = count
                                 curZone = z
-                        self.autoFocusInfo[1] = self.universe.getPlayersInZone(z)
+                        self.autoFocusInfo[1] = self.universe.getPlayersInZone(curZone)
                     countdown = 10
                 countdown -= 1
         
@@ -556,6 +556,7 @@ class GameViewer(framework.CompoundElement):
         self.elements = [self.viewManager, self.pregameMessage]
 
     def updatePregameMessage(self):
+        text = ''
         if self.world.gameState == GameState.InProgress:
             text = ''
         elif self.world.gameState == GameState.PreGame:
@@ -570,6 +571,8 @@ class GameViewer(framework.CompoundElement):
                     text = 'Congratulations!'
                 else:
                     text = 'Better luck next time!'
+            else:
+                text = 'Game is over!'
         self.pregameMessage.setText(text)
                 
     def setTarget(self, target):
