@@ -20,7 +20,7 @@ game to the screen, including menus and other doodads.'''
 
 import pygame
 
-from trosnoth.src.network.client import ClientNetHandler
+from trosnoth.src.network.client import ClientNetHandler, ConnectionFailed
 from trosnoth.src.game import makeIsolatedGame
 from trosnoth.src.gamerecording import replays
 
@@ -113,14 +113,14 @@ class Interface(framework.CompoundElement):
             self.netHandler.disconnect()
             self.netHandler = None
 
-    def connectionFailed(self, reason):
+    def connectionFailed(self, error):
         self.elements = [self.backdrop, self.startupInterface]
-        if True:
-            print 'Unexpected failure in deferred: %s' % (reason.value,)
-            reason.printTraceback()
-            text = 'Internal error'
+        if type(error.value) == ConnectionFailed:
+            text = str(error.value.reason)
         else:
-            text = str(reason.value)
+            text = 'Internal Error'
+            print 'Unexpected failure in deferred: %s' % (error.value,)
+            error.printTraceback()
         d = ConnectionFailedDialog(self.app, text)
         d.Show()
 
