@@ -22,7 +22,6 @@ import time
 import re
 
 from trosnoth.src.utils.jsonImport import json
-from trosnoth.src.utils.statGeneration import generateStats
 from trosnoth.src.utils import browser
 
 import trosnoth.src.trosnothgui.defines as defines
@@ -31,10 +30,10 @@ from trosnoth.src.gui.framework.listbox import ListBox
 from trosnoth.src.gui.framework.elements import TextElement, TextButton
 from trosnoth.src.gui.framework.dialogbox import DialogBox, DialogResult, DialogBoxAttachedPoint
 from trosnoth.src.gui.common import *
+from trosnoth.src.gamerecording.gamerecorder import RecordedGame, RecordedGameException, gameDir, gameExt, recordedGameVersion
 
 from trosnoth.data import getPath, user, makeDirs
 
-from trosnoth.src.network.networkDefines import gameDataProtocol
 
 class SavedGameMenu(framework.CompoundElement):
     def __init__(self, app, startupInterface):
@@ -148,135 +147,133 @@ class SavedGameMenu(framework.CompoundElement):
         self.gameList.index = -1
         self.elements = self.elementsFiles[:]
         if json == None:
-            self.noFiles1Text.setText("Please install json")
-            self.noFiles2Text.setText("to view statistics")
+            self.noFiles1Text.setText('Please install json')
+            self.noFiles2Text.setText('to view statistics')
             return
-        # Get a list of files with the name "*.trosgame"
-        logDir = getPath(user, 'savedGames')
+        # Get a list of files with the name '*.tros'
+        logDir = getPath(user, gameDir)
         makeDirs(logDir)
         fileList = []
 
         for fname in os.listdir(logDir):
-            if fname[-9:] == ".trosgame":
+            if os.path.splitext(fname)[1] == gameExt:
                 fileList.append(fname)
 
         # Assume all files are valid for now
         validFiles = fileList[:]
 
         self.gameInfo = {}
+        oldFound = False
 
         for fname in fileList:
-            gameFile = open(os.path.join(logDir, fname), "r")
-
-            fileInfo = gameFile.readline()[:-1].split(",")
-            fileProtocol = fileInfo[0]
-            
-            if fileProtocol != gameDataProtocol or len(fileInfo) < 3:
-                validFiles.remove(fname)
-                continue
-
-            # Check if the rest of the string is correct
             try:
-                for i in range(1, len(fileInfo) - 1):
-                    fileInfo[i] = int(fileInfo[i])
-            except ValueError:
+                game = RecordedGame(os.path.join(logDir, fname))
+            except RecordedGameException:
                 validFiles.remove(fname)
                 continue
+            except:
+                print 'invalid file: %s' % (fname,)
+                continue
+            else:
+                if game.recordedGameVersion != recordedGameVersion:
+                    validFiles.remove(fname)
+                    oldFound = True
 
-            encodedLines = []
-            
-            for lineCount in range(1, fileInfo[1] + 1):
-                encodedLines.append(gameFile.readline())
-
-            gameInformation = json.loads("".join(encodedLines))
-            gameInformation['filename'] = fname
-            self.gameInfo[fname[:-9]] = gameInformation
+            self.gameInfo[os.path.splitext(fname)[0]] = game
 
         # Sort the games with most recent first.
-        items = [(v['unixTimestamp'], n) for n, v in self.gameInfo.iteritems()]
+        items = [(v.unixTimestamp, n) for n, v in self.gameInfo.iteritems()]
         items.sort(reverse=True)
         items = [n for v,n in items]
         self.gameList.setItems(items)
 
         if len(self.gameInfo) == 0:
             self.elements = self.elementsNoFiles[:]
-            self.listHeaderText.setText("0 available game files:")
-            self.noFiles1Text.setText("You have not yet run any")
-            self.noFiles2Text.setText("games on this computer!")
-        elif len(self.gameInfo) == 1:
-            self.listHeaderText.setText("1 available game file:")
-            self.gameList.index = 0
-            self.updateSidebar(0)
+            self.listHeaderText.setText('0 available game files:')
+            if oldFound:
+                self.noFiles1Text.setText('Some games were found from')
+                self.noFiles2Text.setText('previous Trosnoth versions')
+            else:                
+                self.noFiles1Text.setText('You have not yet run any')
+                self.noFiles2Text.setText('games on this computer')
         else:
-            self.listHeaderText.setText("%d available game files:" % len(self.gameInfo))
+            self.gameList.setIndex(0)
+            self.updateSidebar(0)
+            if len(self.gameInfo) == 1:
+                self.listHeaderText.setText('1 available game file:')
+            else:
+                self.listHeaderText.setText('%d available game files:' % len(self.gameInfo))
             
     def updateSidebar(self, listID):
         # Update the details on the sidebar
         displayName = self.gameList.getItem(listID)
 
         # Server title
-        self.serverNameText.setText(self.gameInfo[displayName]['serverName'])
+        self.serverNameText.setText(self.gameInfo[displayName].alias)
 
         # Map size
-        serverSettings = self.gameInfo[displayName]['serverSettings']
-        self.serverDetailsText.setText("map size: %d x %d" % (serverSettings['halfMapWidth'], serverSettings['mapHeight']))
+        self.serverDetailsText.setText('Map size: %d x %d' % (self.gameInfo[displayName].halfMapWidth,
+                                                              self.gameInfo[displayName].mapHeight))
 
         # Team names
-        if not serverSettings['teamNames']:
-            blueTeam = "Blue"
-            redTeam = "Red"
-        else:
-            blueTeam = serverSettings['teamNames'][0]
-            redTeam = serverSettings['teamNames'][1]
-        self.teamNamesText.setText(blueTeam + " vs " + redTeam)
+        blueTeam = self.gameInfo[displayName].teamAname
+        redTeam = self.gameInfo[displayName].teamBname
+        self.teamNamesText.setText(blueTeam + ' vs ' + redTeam)
 
         # Date and time of match
-        datePython = map(int, self.gameInfo[displayName]['dateTime'].split(","))
-        dateString = time.strftime("%a %d/%m/%y, %H:%M", datePython)
+        datePython = map(int, self.gameInfo[displayName].dateTime.split(','))
+        dateString = time.strftime('%a %d/%m/%y, %H:%M', datePython)
         self.dateText.setText(dateString)
 
         # Length of match
         dateUnix = time.mktime(datePython)
-        lastUnix = time.mktime(map(int, self.gameInfo[displayName]['saveDateTime'].split(",")))
+        if self.gameInfo[displayName].wasFinished():
+            lastUnix = self.gameInfo[displayName].gameFinishedTimestamp
 
-        lengthSeconds = int(lastUnix - dateUnix)
-        lengthMinutes, lengthSeconds = divmod(lengthSeconds, 60)
+            lengthSeconds = int(lastUnix - dateUnix)
+            lengthMinutes, lengthSeconds = divmod(lengthSeconds, 60)
 
-        secPlural = ("s", "")[lengthSeconds == 1]
-        minPlural = ("s", "")[lengthMinutes == 1]
-        if lengthMinutes == 0:
-            lengthString = "%d second%s" % (lengthSeconds,secPlural)
-        else:
-            lengthString = "%d min%s, %d sec%s" % (lengthMinutes, minPlural, lengthSeconds, secPlural)
+            secPlural = ('s', '')[lengthSeconds == 1]
+            minPlural = ('s', '')[lengthMinutes == 1]
+            if lengthMinutes == 0:
+                lengthString = '%d second%s' % (lengthSeconds,secPlural)
+            else:
+                lengthString = '%d min%s, %d sec%s' % (lengthMinutes, minPlural, lengthSeconds, secPlural)
 
-        self.lengthText.setText(lengthString)
+            self.lengthText.setText(lengthString)
         
         # Enable the replay button
-        if self.gameInfo[displayName]['replaySaved']:
-            self.watchButton.setText("watch")
-            self.noReplayText.setText("")
+        if self.gameInfo[displayName].replayFilename is not None and \
+           os.path.exists(self.gameInfo[displayName].replayFilename):
+            self.watchButton.setText('watch')
+            self.noReplayText.setText('')
         else:
-            self.watchButton.setText("")
-            self.noReplayText.setText("unavailable")
+            self.watchButton.setText('')
+            self.noReplayText.setText('unavailable')
 
         # Enabled the stats button
-        if self.gameInfo[displayName]['statsSaved']:
-            self.statsButton.setText("view")
-            self.noStatsText.setText("")
+        if self.gameInfo[displayName].statsFilename is not None and \
+           os.path.exists(self.gameInfo[displayName].statsFilename):
+            self.statsButton.setText('view')
+            self.noStatsText.setText('')
         else:
-            self.statsButton.setText("")
-            self.noStatsText.setText("unavailable")
+            self.statsButton.setText('')
+            self.noStatsText.setText('unavailable')
 
     def watchReplay(self):
         '''Watch replay button was clicked.'''
         # Try to create a replay server.
-        if self.gameList.index != -1:
-            self.startupInterface.replayConnect(self.gameInfo[self.gameList.getItem()]['filename'], self.gameList.getItem())
+        #if self.gameList.index != -1:
+        self.startupInterface.replayConnect(self.gameInfo[self.gameList.getItem()].replayFilename)
 
     def viewStats(self, allGames = False):
         '''View stats button was clicked.'''
-        self.htmlPath = generateStats(self.gameInfo[self.gameList.getItem()]['statsLocation'])
-
+        game = self.gameInfo[self.gameList.getItem()]
+##        try:
+        self.htmlPath = game.generateHtmlFile()
+##        except:
+##            print 'Unable to generate statistics for %s' % (game.filename)
+##        else:
         self.statsGeneratedBox = StatsGeneratedDialog(self.app)
         self.statsGeneratedBox.onClose.addListener(self._dialogClosed)
         self.statsGeneratedBox.Show()
@@ -299,14 +296,14 @@ class StatsGeneratedDialog(DialogBox):
     '''Defines the elements and layout thereof of the 'stats successfully generated' dialog box.'''
 
     def __init__(self, app):
-        super(StatsGeneratedDialog, self).__init__(app, ScaledSize(450, 350), "Statistics File Generated")
+        super(StatsGeneratedDialog, self).__init__(app, ScaledSize(450, 350), 'Statistics File Generated')
         colours = app.theme.colours
 
-        text = ["A HTML file has been",
-                "created containing the",
-                "requested statistics.",
-                "Do you want to",
-                "open this file now?"]
+        text = ['A HTML file has been',
+                'created containing the',
+                'requested statistics.',
+                'Do you want to',
+                'open this file now?']
         textElements = []
 
         yValue = 10
@@ -321,14 +318,14 @@ class StatsGeneratedDialog(DialogBox):
         # OK Button
         okButton = TextButton(app, Location(DialogBoxAttachedPoint(
                               self, ScaledSize(-100,290), 'midtop'), 'midtop'),
-                              "Yes", font, colours.mainMenuColour, colours.white)
+                              'Yes', font, colours.mainMenuColour, colours.white)
         
         okButton.onClick.addListener(lambda sender: self.ok())
 
         # Cancel Button
         cancelButton = TextButton(app, Location(DialogBoxAttachedPoint(
                                   self, ScaledSize(100,290), 'midtop'), 'midtop'),
-                                  "No", font, colours.mainMenuColour, colours.white)
+                                  'No', font, colours.mainMenuColour, colours.white)
         
         cancelButton.onClick.addListener(lambda sender: self.cancel())
 
