@@ -15,8 +15,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
-from trosnoth.src.utils import logging
 from trosnoth.src.utils.message import Message
+from twisted.internet import reactor
 
 class Component(object):
     def __init__(self):
@@ -26,7 +26,7 @@ class Component(object):
         for k in dir(self):
             v = getattr(self, k)
             if isinstance(v, Plug):
-                plugs[v] = plugsByName[k] = BoundPlug(v, self)
+                plugs[v] = plugsByName[k] = BoundPlug(v, self, k)
 
         # Go through methods and check for handlers.
         for k in dir(self):
@@ -55,39 +55,39 @@ class UnboundPlug(object):
     plug is unbound. Plug is an alias for UnboundPlug in order to make more
     sense in written code.
     '''
+    def __init__(self):
+        self._defaultHandler = None
+
+    def defaultHandler(self, fn):
+        '''
+        Decorator that specifies a method as the default message handler.
+        '''
+        return handler(None, self)(fn)
+
 Plug = UnboundPlug
 
 def queueMessage(target, message):
-    # Note: it may be sensible to use a callLater here instead.
+#    reactor.callLater(0, target._receive, message)
     try:
         target._receive(message)
     except:
+        from trosnoth.src.utils import logging
         logging.writeException()
 
 class UnhandledMessage(Exception):
     pass
 
-class BoundPlug(object):
-    def __init__(self, plug, obj):
-        self.plug = plug
-        self.obj = obj
+class BasePlug(object):
+    def __init__(self):
         self.targets = []
-        self._methods = {}
 
     def send(self, message):
         for target in self.targets:
             queueMessage(target, message)
 
     def _receive(self, message):
-        # Find the correct handler.
-        try:
-            method = self._methods[type(message)]
-        except KeyError:
-            print self._methods
-            raise UnhandledMessage('%s does not handle %s' % (self.obj, message))
-
-        # Call this handler.
-        method(self.obj, message)
+        raise UnhandledMessage('BasePlug does not handle %s' % (self.obj,
+                type(message)))
 
     def connectPlug(self, plug):
         '''
@@ -123,6 +123,43 @@ class BoundPlug(object):
         except KeyError:
             pass
 
+class DynamicPlug(BasePlug):
+    '''
+    Plug that can be created and used at run-time.
+    '''
+    def __init__(self, receiverFn):
+        BasePlug.__init__(self)
+        self._receive = receiverFn
+
+class BoundPlug(BasePlug):
+    def __init__(self, plug, obj, name):
+        BasePlug.__init__(self)
+        self.plug = plug
+        self.obj = obj
+        self._name = name
+        self._methods = {}
+
+    def __str__(self):
+        return '%r.%s' % (self.obj, self._name)
+
+    def __repr__(self):
+        return '<BoundPlug %r of %r>' % (self._name, self.obj)
+
+    def _receive(self, message):
+        # Find the correct handler.
+        try:
+            method = self._methods[type(message)]
+        except KeyError:
+            try:
+                # Get the default.
+                method = self._methods[None]
+            except KeyError:
+                raise UnhandledMessage('%s does not handle %s' % (self.obj,
+                        type(message)))
+
+        # Call this handler.
+        method(self.obj, message)
+
 class Handler(object):
     def __init__(self, method, message, plug=None):
         self.method = method
@@ -137,3 +174,20 @@ def handler(message, plug=None):
             return method
         return Handler(method, message, plug)
     return handler
+
+
+class Adaptor(Component):
+    '''
+    Simple component with two connected plugs, plug1 and plug2.
+    '''
+
+    plug1 = Plug()
+    plug2 = Plug()
+
+    @plug1.defaultHandler
+    def fromPlug1(self, msg):
+        self.plug2.send(msg)
+
+    @plug2.defaultHandler
+    def fromPlug2(self, msg):
+        self.plug1.send(msg)
