@@ -29,4 +29,4 @@ class Event(object):
         for call in self.listeners:
             call(*args, **kwargs)
             
-    __exec__ = execute
+    __call__ = execute
